import React, { useState, useEffect } from "react";
import { Link } from "react-router-dom";
import { Col, Row, Card } from "react-bootstrap";
import { connect, useDispatch } from "react-redux";
import { actions as cartActions } from "@redux/cartRedux";
import { actions as favoriteActions } from "@redux/favoriteRedux";
import cartServices from "services/cartServices";
import favoriteServices from "services/favouriteServices";
import { isUserLoggedIn } from "services/userServices";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import Rating from "react-rating";
import { toast } from "react-toastify";
import ProductDataAccess from "dataAccess/productDataAccess";
import SliderDataAccess from "dataAccess/sliderDataAccess";

const ProductBox = (props) => {
  const productItem = props.productItem;

  const [currency, setCurrency] = useState(null);

  useEffect(() => {
    SliderDataAccess.getSettingData()
      .then((data) => {
        setCurrency(data.currency_symbol);
      })
      .catch((error) => {});
  }, []);

  const dispatch = useDispatch();

  const requestToStock = (productId) => {
    ProductDataAccess.ProductRequestToStock(productId)
      .then((data) => {
        toast.success(data);
      })
      .catch((error) => {
        toast.error("Login first and send request again");
      });
  };

  return (
    <Col xl={3} lg={3} md={4} sm={8} xs={10} className="product-card-container">
      <div className="new-card-design">
        <div className="card">
          <div className="stock-new-design">
            {productItem.is_available == 1 ? (
              <div>
                {productItem.is_visible_stock == 1 ? (
                  <h6 className="stock-text">
                    In Stock
                    <span className="">({productItem.quantity})</span>
                  </h6>
                ) : (
                  <h6 className="stock-text2">In Stock</h6>
                )}
              </div>
            ) : (
              <h6 className="stock-text3">Out Of Stock</h6>
            )}
          </div>
          <Link
            to={"/product-details/" + productItem.slug}
            className="product-image-big"
          >
            <img
              className="card-img-top"
              src={productItem.image1}
              alt="Cardimagecap"
            />
          </Link>
          <div className="card-body">
            <div className="d-flex">
              <div>
                <div style={{ height: "30px" }}>
                  <span>
                    {productItem.name.length > 20 ? (
                      <p className="card-product-name">
                        {productItem.name.substring(0, 22) + "..."}
                      </p>
                    ) : (
                      <p className="card-product-name">{productItem.name}</p>
                    )}
                  </span>
                </div>
                <div className="rating-content" style={{ color: "gold" }}>
                  {productItem.rating.avg_rating !== 0 && (
                    <span
                      style={{
                        marginRight: "3px",
                        fontSize: "12px",
                      }}
                    >
                      <Rating
                        fullSymbol="fa fa-star"
                        emptySymbol="fa fa-star-o"
                        readonly
                        initialRating={productItem.rating.avg_rating}
                      />
                      <span style={{ color: "red" }}>
                        ({productItem.rating.rating_number})
                      </span>
                    </span>
                  )}
                  {productItem.rating.avg_rating === 0 && (
                    <div
                      style={{
                        color: "#FFD700",
                        marginTop: "9px",
                      }}
                    >
                      <div
                        className="d-flex"
                        style={{
                          fontSize: "11px",
                        }}
                      >
                        <i className="far fa-star mr-1"></i>
                        <i className="far fa-star mr-1"></i>
                        <i className="far fa-star mr-1"></i>
                        <i className="far fa-star mr-1"></i>
                        <i className="far fa-star mr-1"></i>
                      </div>
                    </div>
                  )}
                </div>
                {/* <div>
                  <div>
                    <p className="text-secondary">
                      {productItem.unit_quantity} {productItem.unit.name}
                    </p>
                  </div>
                </div> */}

                <span className="price-and-cart-btn">
                  <p className="product-price">
                    {currency}{" "}
                    {productItem.discount_price == 0
                      ? productItem.price
                      : productItem.discount_price}{" "}
                    {productItem.discount_price != 0 && (
                      <del className="product-before-price">
                        {currency} {productItem.price}
                      </del>
                    )}
                  </p>
                </span>
              </div>
              <div className="ml-auto">
                <div>
                  {favoriteServices.isProductOnFavorite(
                    productItem.id,
                    props.favorite.favorite
                  ) ? (
                    <span
                      onClick={() => {
                        dispatch(
                          favoriteActions.removeProductFromFavorite(
                            productItem.id,
                            isUserLoggedIn(props.user.user)
                          )
                        );
                      }}
                      className="favorite-icon"
                    >
                      <img
                        className="like"
                        src={process.env.PUBLIC_URL + "/images/likered.png"}
                        alt=""
                      />
                    </span>
                  ) : (
                    <span
                      onClick={() => {
                        dispatch(
                          favoriteActions.addProductToFavorite(
                            productItem.id,
                            isUserLoggedIn(props.user.user)
                          )
                        );
                      }}
                      className="favorite-icon"
                    >
                      <img
                        className="like"
                        src={process.env.PUBLIC_URL + "/images/like.png"}
                        alt=""
                      />
                    </span>
                  )}
                </div>
                <div>
                  {productItem.is_available !== 0 ? (
                    <Link to={"/compair-product-detail/" + productItem.slug}>
                      <h6
                        className="compair-text"
                        style={{
                          // width: "70px",
                          // padding: "2px 2px",
                          color: "#40BFFF",
                          // borderColor: "#40BFFF",
                          fontSize: "14px",
                        }}
                      >
                        Compare
                      </h6>
                    </Link>
                  ) : (
                    ""
                  )}
                </div>
                <div className="row justify-content-between">
                  <div className="col-auto">
                    {productItem.is_available === 0 ? (
                      <div className="pb-3">
                        <p
                          className="cart-button"
                          style={{
                            width: "90px",
                            padding: "0px 2px 3px 2px",
                          }}
                          onClick={() => {
                            requestToStock(productItem.id);
                          }}
                        >
                          <span
                            className="request-to-stock-btn-text"
                            style={{ fontSize: "11px" }}
                          >
                            Notify me
                          </span>
                        </p>
                        <p
                          className="out-of-stock"
                          style={{
                            fontSize: "13px",
                          }}
                        >
                          {" "}
                          {/* Out Of Stock{" "} */}
                        </p>
                      </div>
                    ) : cartServices.isProductOnCart(
                        productItem.id,
                        props.cart
                      ) ? (
                      <p
                        className="cart-button"
                        style={{
                          width: "90px",
                          padding: "0px 2px 3px 2px",
                        }}
                      >
                        <span className="before-click">
                          <span className="cart">
                            <img
                              className="cart-image"
                              src={
                                process.env.PUBLIC_URL + "/images/card-red.png"
                              }
                              alt=""
                              style={{ width: "12px" }}
                            />
                          </span>
                          <span
                            className="cart responsive-width"
                            style={{ fontSize: "11px" }}
                          >
                            Added
                          </span>
                        </span>
                      </p>
                    ) : (
                      // <p className="cart-btn-after-click">
                      //   <span className="after-click">
                      //     <span
                      //       className="cart-minus-sign"
                      //       onClick={() => {
                      //         props.dispatch(
                      //           cartActions.decreaseProductQuantity(
                      //             productItem.id,
                      //             cartServices.getCartQuantity(
                      //               productItem.id,
                      //               props.cart
                      //             ),
                      //             isUserLoggedIn(props.user.user)
                      //           )
                      //         );
                      //       }}
                      //     >
                      //       <FontAwesomeIcon icon="minus" />
                      //     </span>
                      //     &nbsp;
                      //     <span>
                      //       {cartServices.getCartQuantity(
                      //         productItem.id,
                      //         props.cart
                      //       )}
                      //     </span>
                      //     &nbsp;
                      //     <span
                      //       className="cart-plus-sign"
                      //       onClick={() => {
                      //         cartServices.getCartQuantity(
                      //           productItem.id,
                      //           props.cart
                      //         ) === productItem.quantity
                      //           ? toast.error("stock out")
                      //           : dispatch(
                      //               cartActions.increaseProductQuantity(
                      //                 productItem.id,
                      //                 cartServices.getCartQuantity(
                      //                   productItem.id,
                      //                   props.cart
                      //                 ),
                      //                 isUserLoggedIn(props.user.user)
                      //               )
                      //             );
                      //       }}
                      //     >
                      //       <FontAwesomeIcon icon="plus" />
                      //     </span>
                      //   </span>
                      // </p>
                      <p
                        className="cart-button"
                        style={{
                          width: "90px",
                          padding: "0px 2px 3px 2px",
                        }}
                        onClick={() => {
                          dispatch(
                            cartActions.addProductToCart(
                              productItem.id,
                              isUserLoggedIn(props.user.user)
                            )
                          );
                        }}
                      >
                        <span className="before-click">
                          <span className="cart">
                            <img
                              className="cart-image"
                              src={
                                process.env.PUBLIC_URL + "/images/card-red.png"
                              }
                              alt=""
                              style={{ width: "12px" }}
                            />
                          </span>
                          <span
                            className="cart responsive-width"
                            style={{ fontSize: "11px" }}
                          >
                            Add to Cart
                          </span>
                        </span>
                      </p>
                    )}
                  </div>
                  <div className="ml-auto">
                    {/* {productItem.is_available !== 0 ? (
                                <Link
                                  to={"/compair-product-detail/" + productItem.slug}
                                >
                                  <h6
                                    className="mt-1"
                                    style={{
                                      // width: "70px",
                                      // padding: "2px 2px",
                                      color: "#40BFFF",
                                      // borderColor: "#40BFFF",
                                      fontSize: "14px",
                                    }}
                                  >
                                    Compair
                                  </h6>
                                </Link>
                              ) : (
                                ""
                              )} */}
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </Col>
  );
};

const mapStateToProps = ({ product, cart, favorite, user }) => {
  return { product, cart: cart.cart, favorite, user };
};
export default connect(mapStateToProps)(ProductBox);
